pub struct PersonName {
pub family_names: Option<String>,
pub given_names: Option<String>,
pub name_particle: Option<String>,
pub name_suffix: Option<String>,
pub affiliation: Option<String>,
pub meta: NameMeta,
}Expand description
The name of a person.
At least one field must be provided.
Fields
family_names: Option<String>Family names.
This includes combinations of given and patronymic forms, such as Guðmundsdóttir or bin Osman; double names with or without hyphen, such as Leutheusser-Schnarrenberger or Sánchez Vicario. It can potentially also specify names that include prepositions or (nobiliary) particles, especially if they occur in between family names such as in Spanish- or Portuguese-origin names, such as Fernández de Córdoba.
given_names: Option<String>Given or chosen names.
name_particle: Option<String>The person’s name particle.
For example, a nobiliary particle, or a preposition meaning of or from (for example von in Alexander von Humboldt).
This may also be called the “non-dropping particle”.
name_suffix: Option<String>The person’s name suffix.
For example, Jr. for Sammy Davis Jr. or III for Frank Edwin Wright III.
affiliation: Option<String>Affiliation (e.g. organisation membership).
meta: NameMetaCommon name metadata fields.